@@ -17,7 +17,7 @@
 
 static double distance(double x1, double y1, double x2, double y2){
 
-  return(pythag(x1-x2,y1-y2));
+  return(hypot(x1-x2,y1-y2));
 
 }
 
